@@ -1,5 +1,6 @@
 // -*- C++ -*-
-/* Copyright (C) 1989, 1990, 1991, 1992, 2000 Free Software Foundation, Inc.
+/* Copyright (C) 1989, 1990, 1991, 1992, 2000, 2001, 2002
+   Free Software Foundation, Inc.
      Written by James Clark (jjc@jclark.com)
 
 This file is part of groff.
@@ -18,12 +19,11 @@ You should have received a copy of the GNU General Public License along
 with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-#include <stdio.h>
-#include <string.h>
+#include "lib.h"
+
 #include <ctype.h>
 #include <assert.h>
 #include <stdlib.h>
-#include "lib.h"
 #include "errarg.h"
 #include "error.h"
 #include "font.h"
@@ -45,7 +45,6 @@ private:
   int ascii_index[256];
   int small_number_index[NSMALL];
   PTABLE(int) table;
-  int lookup_char(const char *, int);
 };
 
 character_indexer::character_indexer()
