@@ -59,14 +59,10 @@ extern "C" const char *Version_string;
 #include "pushback.h"
 #include "html-strings.h"
 
+#define DEFAULT_LINE_LENGTH        7   // inches wide
 #define DEFAULT_IMAGE_RES        100   // number of pixels per inch resolution
 #define IMAGE_BOARDER_PIXELS       0
-#define MAX_WIDTH                  8   // inches
 #define INLINE_LEADER_CHAR      '\\'
-#define A4_LENGTH             841890   // taken from devps/Makefile.sub
-#define LETTER_LENGTH         792000   // taken from devps/Makefile.sub
-#define A4_OFFSET                  0
-#define LETTER_OFFSET             50   // 50/72 of an inch
 
 #define TRANSPARENT  "-background white -transparent white"
 #define MIN_ALPHA_BITS             0
@@ -108,7 +104,6 @@ static char *image_template   = NULL;           // image template filename
 static char *macroset_template= NULL;           // image template passed to troff by -D
 static int   troff_arg        = 0;              // troff arg index
 static char *image_dir        = NULL;           // user specified image directory
-static char *gsPaper          = NULL;           // the paper size that gs must use
 static int   textAlphaBits    = MAX_ALPHA_BITS;
 static int   graphicAlphaBits = MAX_ALPHA_BITS;
 static char *antiAlias        = NULL;           // antialias arguments we pass to gs.
@@ -215,52 +210,6 @@ static unsigned int get_resolution (void)
   return 0;
 }
 
-/*
- *  get_papersize - returns an integer determining the paper length from devps/DESC
- */
-
-static int get_papersize (void)
-{
-  char *pathp;
-  FILE *f;
-  int res;
-  f = font_path.open_file("devps/DESC", &pathp);
-  if (f == 0)
-    fatal("can't open devps/DESC");
-  while (get_line(f)) {
-    int n = sscanf(linebuf, "paperlength %d", &res);
-    if (n >= 1) {
-      fclose(f);
-      return res;
-    }
-    if (!strncmp(linebuf, "papersize", 9)) {
-      double length;
-      char *p = linebuf + 9;
-      while (*p == ' ' || *p == '\t')
-	p++;
-      if (font::scan_papersize(p, 0, &length, 0)) {
-	fclose(f);
-	return int(length * postscriptRes + 0.5);
-      }
-      else
-	fatal("bad argument to `papersize' keyword in devps/DESC");
-    }
-  }
-  fatal("can't find `papersize' or `paperlength' keyword in devps/DESC");
-  return 0;
-}
-
-/*
- *  determine_vertical_offset - works out the default vertical offset from
- *                              the page length
- */
-
-static void determine_vertical_offset (void)
-{
-  vertical_offset = ((A4_LENGTH-get_papersize())*72)/postscriptRes;
-  gsPaper = "-sPAPERSIZE=a4";
-}
-
 /*
  *  html_system - a wrapper for system()
  */
@@ -789,6 +738,10 @@ public:
   imageList();
   ~imageList();
   void  add(int x1, int y1, int x2, int y2, int page, int res, int maxx, char *name);
+  void  createImages (void);
+  int   createPage (int pageno);
+  void  createImage (imageItem *i);
+  int   getMaxX (int pageno);
 };
 
 /*
@@ -817,7 +770,7 @@ imageList::~imageList ()
  *  createPage - creates one image of, page pageno, from the postscript file.
  */
 
-static int createPage (int pageno)
+int imageList::createPage (int pageno)
 {
   char *s;
 
@@ -825,6 +778,10 @@ static int createPage (int pageno)
     return 0;
 
   if (currentPageNo >= 1) {
+    /*
+     *  we need to unlink the files which change each time a new page is processed.
+     *  The final unlink is done by xtmpfile when pre-grohtml exits.
+     */
     unlink(imagePageName);
     unlink(psPageName);
   }
@@ -853,10 +810,13 @@ static int createPage (int pageno)
   html_system(s, 1);
   
   s = make_message("echo showpage | "
-		   "gs%s %s -q -dBATCH -dSAFER -sDEVICE=%s -r%d %s"
+		   "gs%s -q -dBATCH -dSAFER "
+		   "-dDEVICEHEIGHTPOINTS=792 "
+		   "-dDEVICEWIDTHPOINTS=%d -dFIXEDMEDIA=true "
+		   "-sDEVICE=%s -r%d %s "
 		   "-sOutputFile=%s %s -\n",
 		   EXE_EXT,
-		   gsPaper,
+		   (getMaxX(pageno) * image_res) / postscriptRes,
 		   image_device,
 		   image_res,
 		   antiAlias,
@@ -902,11 +862,28 @@ int max (int x, int y)
   }
 }
 
+/*
+ *  getMaxX - returns the largest right hand position for any image on, pageno
+ */
+
+int imageList::getMaxX (int pageno)
+{
+  imageItem *h = head;
+  int x        = postscriptRes * DEFAULT_LINE_LENGTH;
+
+  while (h != NULL) {
+    if (h->pageNo == pageno)
+      x = max(h->X2, x);
+    h = h->next;
+  }
+  return x;
+}
+
 /*
  *  createImage - generates a minimal png file from the set of page images.
  */
 
-static void createImage (imageItem *i)
+void imageList::createImage (imageItem *i)
 {
   if (i->X1 != -1) {
     char *s;
@@ -962,7 +939,20 @@ void imageList::add (int x1, int y1, int x2, int y2, int page, int res, int maxx
     tail->next = i;
     tail = i;
   }
-  createImage(i);
+}
+
+/*
+ *  createImages - foreach image descriptor on the imageList, create the actual image.
+ */
+
+void imageList::createImages (void)
+{
+  imageItem *h = head;
+
+  while (h != NULL) {
+    createImage(h);
+    h = h->next;
+  }
 }
 
 static imageList listOfImages;  // list of images defined by the region file.
@@ -1012,7 +1002,7 @@ static void generateImages (char *regionFileName)
       int y1     = f->readInt();
       int x2     = f->readInt();
       int y2     = f->readInt();
-      int maxx   = max(f->readInt(), MAX_WIDTH*image_res);
+      int maxx   = f->readInt();
       char *name = f->readString();
       int res    = postscriptRes;
       listOfImages.add(x1, y1, x2, y2, page, res, maxx, name);
@@ -1030,10 +1020,13 @@ static void generateImages (char *regionFileName)
       fputc(f->getPB(), stderr);
     }
   }
+  
+  listOfImages.createImages();
   if (show_progress) {
     fprintf(stderr, "done\n");
     fflush(stderr);
   }
+  delete f;
 }
 
 /*
@@ -1072,7 +1065,7 @@ static void waitForChild (PID_T pid)
   PID_T waitpd;
   int   status;
 
-  waitpd = wait(&status);
+  waitpd = WAIT(&status, pid, _WAIT_CHILD);
   if (waitpd != pid)
     sys_fatal("wait");
 }
@@ -1254,6 +1247,10 @@ int char_buffer::do_image(int argc, char *argv[])
   argv = addRegDef(argc, argv, s.contents());
   argc++;
 
+  // override local settings and produce a page size letter postscript file
+  argv = addRegDef(argc, argv, "-P-pletter");
+  argc++;
+
   if (pipe(pdes) < 0)
     sys_fatal("pipe");
 
@@ -1367,7 +1364,6 @@ int scanArguments (int argc, char **argv)
       break;
     case 'o':
       vertical_offset = atoi(optarg);
-      gsPaper = "";  // do not specify the paper size now
       break;
     case 'p':
       show_progress = TRUE;
@@ -1424,7 +1420,7 @@ static int makeTempFiles (void)
   /* psPageName contains a single page of postscript */
   f = xtmpfile(&psPageName,
 	       PS_TEMPLATE_LONG, PS_TEMPLATE_SHORT,
-	       FALSE);
+	       TRUE);
   if (f == NULL) {
     sys_fatal("xtmpfile");
     return -1;
@@ -1434,7 +1430,7 @@ static int makeTempFiles (void)
   /* imagePageName contains a bitmap image of the single postscript page */
   f = xtmpfile(&imagePageName,
 	       PAGE_TEMPLATE_LONG, PAGE_TEMPLATE_SHORT,
-	       FALSE);
+	       TRUE);
   if (f == NULL) {
     sys_fatal("xtmpfile");
     return -1;
@@ -1444,7 +1440,7 @@ static int makeTempFiles (void)
   /* psFileName contains a postscript file of the complete document */
   f = xtmpfile(&psFileName,
 	       PS_TEMPLATE_LONG, PS_TEMPLATE_SHORT,
-	       FALSE);
+	       TRUE);
   if (f == NULL) {
     sys_fatal("xtmpfile");
     return -1;
@@ -1454,7 +1450,7 @@ static int makeTempFiles (void)
   /* regionFileName contains a list of the images and their boxed coordinates */
   f = xtmpfile(&regionFileName,
 	       REGION_TEMPLATE_LONG, REGION_TEMPLATE_SHORT,
-	       FALSE);
+	       TRUE);
   if (f == NULL) {
     sys_fatal("xtmpfile");
     return -1;
@@ -1473,7 +1469,6 @@ int main(int argc, char **argv)
   int ok=1;
 
   postscriptRes = get_resolution();
-  determine_vertical_offset();
   i = scanArguments(argc, argv);
   setupAntiAlias();
   checkImageDir();
